"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EvmContracts = void 0;
const wormhole_sdk_1 = require("@certusone/wormhole-sdk");
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
/**
 * @category EVM
 * Evm Contracts class. Contains methods for accessing ts interfaces for all available contracts
 */
class EvmContracts extends connect_sdk_1.ContractsAbstract {
    constructor(wormholeBase) {
        super();
        this.wormhole = wormholeBase;
        this._contracts = new Map();
        const chains = (0, connect_sdk_1.filterByContext)(wormholeBase.conf, connect_sdk_1.Context.EVM);
        chains.forEach((c) => {
            this._contracts.set(c.key, c.contracts);
        });
    }
    getContracts(chain) {
        const chainName = this.wormhole.toChainName(chain);
        return this._contracts.get(chainName);
    }
    mustGetContracts(chain) {
        const chainName = this.wormhole.toChainName(chain);
        const contracts = this._contracts.get(chainName);
        if (!contracts)
            throw new Error(`no EVM contracts found for ${chain}`);
        return contracts;
    }
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, undefined if not found
     */
    getCore(chain) {
        const connection = this.wormhole.mustGetConnection(chain);
        const address = this.mustGetContracts(chain).core;
        if (!address)
            return undefined;
        return wormhole_sdk_1.ethers_contracts.Wormhole__factory.connect(address, connection);
    }
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    mustGetCore(chain) {
        const core = this.getCore(chain);
        if (!core)
            throw new Error(`Core contract for domain ${chain} not found`);
        return core;
    }
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, undefined if not found
     */
    getBridge(chain) {
        const connection = this.wormhole.mustGetConnection(chain);
        const address = this.mustGetContracts(chain).token_bridge;
        if (!address)
            return undefined;
        return wormhole_sdk_1.ethers_contracts.Bridge__factory.connect(address, connection);
    }
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    mustGetBridge(chain) {
        const bridge = this.getBridge(chain);
        if (!bridge)
            throw new Error(`Bridge contract for domain ${chain} not found`);
        return bridge;
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain) {
        const connection = this.wormhole.mustGetConnection(chain);
        const address = this.mustGetContracts(chain).nft_bridge;
        if (!address)
            return undefined;
        return wormhole_sdk_1.ethers_contracts.NFTBridge__factory.connect(address, connection);
    }
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain) {
        const nftBridge = this.getNftBridge(chain);
        if (!nftBridge)
            throw new Error(`NFT Bridge contract for domain ${chain} not found`);
        return nftBridge;
    }
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, undefined if not found
     */
    getTokenBridgeRelayer(chain) {
        const connection = this.wormhole.mustGetConnection(chain);
        const address = this.mustGetContracts(chain).relayer;
        if (!address)
            return undefined;
        return connect_sdk_1.TokenBridgeRelayer__factory.connect(address, connection);
    }
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, errors if not found
     */
    mustGetTokenBridgeRelayer(chain) {
        const relayer = this.getTokenBridgeRelayer(chain);
        if (!relayer)
            throw new Error(`Token Bridge Relayer contract for domain ${chain} not found`);
        return relayer;
    }
}
exports.EvmContracts = EvmContracts;
//# sourceMappingURL=contracts.js.map